package tourplaner.ui;

import javafx.fxml.Initializable;
import javafx.scene.control.Label;
import javafx.scene.control.TableColumn;
import javafx.scene.control.TableView;
import javafx.scene.control.cell.PropertyValueFactory;
import tourplaner.business.ConfigHelper;
import tourplaner.object.Tour;
import tourplaner.viewmodels.ViewModel;

import java.net.URL;
import java.util.ResourceBundle;

public class TourDetailsTabController implements Initializable {
    public TableView<Tour> beschreibungTableView;
    public TableColumn<Tour, String> startCol, zielCol, dauerCol, streckeCol, nameCol;

    @Override
    public void initialize(URL url, ResourceBundle resourceBundle) {
    }

    /**
     * Ladet die daten der ausgewählten tour
     * @param viewModel Das aktuelle view Model
     * @param selectedItem Das selected tour item
     */
    public void syncTour(ViewModel viewModel, String selectedItem){
        langToFxml();
        try {
            beschreibungTableView.getItems().clear(); //Leert die Table View komplett
        }catch (NullPointerException e){
            beschreibungTableView.setItems(viewModel.getTourData(new ProgressBar("Load"), 100));
        }
        beschreibungTableView.getItems().add(viewModel.getTour(selectedItem));
    }

    /**
     * Löscht die Tour daten
     */
    public void delTour(){
        this.beschreibungTableView.getItems().clear(); //löscht alles aus der tabelle
    }

    /**
     * Schreibt das keine Tour selected ist
     */
    public void keineSelected(){
        beschreibungTableView.setPlaceholder(new Label( ConfigHelper.getLangIniString("keinetourselected")));
    }

    /**
     * Setzt die Table view Cell Value Factory
     */
    public void tourListSelectItem(){
        this.startCol.setCellValueFactory(new PropertyValueFactory<>("start"));
        zielCol.setCellValueFactory(new PropertyValueFactory<>("ziel"));
        dauerCol.setCellValueFactory(new PropertyValueFactory<>("dauer"));
        streckeCol.setCellValueFactory(new PropertyValueFactory<>("strecke"));
        nameCol.setCellValueFactory(new PropertyValueFactory<>("name"));
    }

    /**
     * Setzt die aktuell gewählte sprache auf die Table view
     */
    public void langToFxml(){
        this.nameCol.setText(ConfigHelper.getLangIniString("fname"));
        this.streckeCol.setText(ConfigHelper.getLangIniString("fstrecke"));
        this.dauerCol.setText(ConfigHelper.getLangIniString("fdauer"));
        this.zielCol.setText(ConfigHelper.getLangIniString("fziel"));
        this.startCol .setText(ConfigHelper.getLangIniString("fstart"));
    }
}
